@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::FLORA;
 our $AUTHORITY = 'cpan:FLORA';
 # ABSTRACT: Build your distributions like FLORA does
-$Dist::Zilla::PluginBundle::FLORA::VERSION = '0.15';
+$Dist::Zilla::PluginBundle::FLORA::VERSION = '0.16';
 use Moose 1.00;
 use Method::Signatures::Simple;
 use Moose::Util::TypeConstraints;
@@ -11,6 +11,11 @@ use MooseX::Types::Moose qw(Bool Str CodeRef);
 use MooseX::Types::Structured 0.20 qw(Map Dict Optional);
 use namespace::autoclean -also => 'lower';
 
+with
+    'Dist::Zilla::Role::PluginBundle::Easy',
+    'Dist::Zilla::Role::PluginBundle::PluginRemover' => { -version => '0.103' },
+    'Dist::Zilla::Role::PluginBundle::Config::Slicer';
+
 
 has dist => (
     is       => 'ro',
@@ -279,6 +284,7 @@ override BUILDARGS => method ($class:) {
     return { %{ $args->{payload} }, %{ $args } };
 };
 
+sub configure;  # forward declaration for role application
 method configure {
     $self->add_bundle('@Basic');
 
@@ -305,6 +311,8 @@ method configure {
             authority   => $self->authority,
             do_metadata => 1,
         }],
+        [ 'MinimumPerl'         => { ':version' => '1.006', configure_finder => ':NoFiles' } ],
+
         ['Test::EOL' => {
             ':version' => '0.14',
             trailing_whitespace => !$self->disable_trailing_whitespace_tests,
@@ -312,6 +320,8 @@ method configure {
         ['Test::NoTabs' => {
             ':version' => '0.09',
         }],
+        ['Test::NewVersion'],
+        [ 'Test::ReportPrereqs' => { ':version' => '0.019', verify_prereqs => 1 } ],
     );
 
 
@@ -326,11 +336,6 @@ method configure {
     $self->add_plugins('AutoPrereqs') if $self->auto_prereqs;
 }
 
-with
-    'Dist::Zilla::Role::PluginBundle::Easy',
-    'Dist::Zilla::Role::PluginBundle::PluginRemover' => { -version => '0.103' },
-    'Dist::Zilla::Role::PluginBundle::Config::Slicer';
-
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -369,6 +374,11 @@ It is roughly equivalent to:
   [PodCoverageTests]
   [Test::NoTabs]
   [Test::EOL]
+  [Test::NewVersion]
+
+  [Test::ReportPrereqs]
+  :version = 0.019
+  verify_prereqs = 1
 
   [MetaResources]
   repository.type   = git
@@ -382,6 +392,10 @@ It is roughly equivalent to:
   authority   = cpan:FLORA
   do_metadata = 1
 
+  [MinimumPerl]
+  :version = 1.006
+  configure_finder = :NoFiles
+
   [PodWeaver]
   config_plugin = @FLORA
 
